@@ -4,17 +4,15 @@ import shlex
 import configparser
 from subprocess import Popen, PIPE
 from dogtail.rawinput import typeText, pressKey, keyCombo
-from dogtail.tree import root
-from qecore.utility import run
+from qecore.utility import run, overview_action
 from qecore.logger import QELogger
 
 log = QELogger()
 
 class Application:
     def __init__(self, component, a11y_app_name=None, desktop_file_exists=True,
-                 desktop_file_name="", desktop_file_path="",
-                 app_process_name="", shell=None, session_type="",
-                 session_desktop="", logging=False):
+                 desktop_file_name="", desktop_file_path="", app_process_name="",
+                 shell=None, session_type="", session_desktop="", kiosk=None):
         """
         .. note::
 
@@ -38,25 +36,19 @@ class Application:
 
         :type app_process_name: str
         :param app_process_name: Name of application process if not same as component.
-
-        :type logging: bool
-        :param logging: Turn on logging of this submodule. Passed from sandbox.
         """
 
-        self.logging = logging
-
-        if self.logging:
-            log.info(" ".join((
+        log.info(" ".join((
                 f"__init__(self, component={component}, a11y_app_name={a11y_app_name},",
                 f"desktop_file_exists={desktop_file_exists},",
                 f"desktop_file_name={desktop_file_name},",
                 f"desktop_file_path={desktop_file_path},",
                 f"app_process_name={app_process_name}, shell='shell',",
-                f"session_type={session_type}, session_desktop={session_desktop},",
-                f"logging={str(logging)})"
-            )))
+                f"session_type={session_type}, session_desktop={session_desktop})"
+        )))
 
         self.shell = shell
+        self.kiosk = kiosk
         self.session_type = session_type
         self.session_desktop = session_desktop
         self.pid = None
@@ -75,7 +67,7 @@ class Application:
         self.get_desktop_file_data()
 
         if 'Flatpak' not in f'{type(self)}':
-            # Preserving old api names of functions
+            # Preserving old api names of functions.
             self.getDesktopFileData = self.get_desktop_file_data
             self.getRoot = self.get_root
             self.isRunning = self.is_running
@@ -92,11 +84,12 @@ class Application:
             Do **NOT** call this by yourself. This method is called by :func:`__init__`.
         """
 
-        if self.logging:
-            log.info(f"{self.component} get_desktop_file_data(self)")
+        log.info(f"{self.component} get_desktop_file_data(self)")
 
-        if self.desktop_file_exists: # zenity/gnome-shell do not have desktop file
+        # zenity/gnome-shell do not have desktop file.
+        if self.desktop_file_exists:
             if self.desktop_file_path:
+                log.info(f"get_desktop_file_data: loading user provided .desktop file: '{self.desktop_file_path}'")
                 desktop_file = self.desktop_file_path
             else:
                 desktop_run = run(" ".join((
@@ -105,10 +98,12 @@ class Application:
                     "grep .desktop |",
                     f"grep '{self.desktop_file_name}'"
                 )), verbose=True)
+
                 if desktop_run[1] != 0:
                     raise Exception(f"Desktop file of application '{self.component}' was not found.")
 
                 desktop_file = desktop_run[0].strip("\n")
+                log.info(f"get_desktop_file_data: .desktop file found: '{desktop_file}'")
 
             desktop_files_list = desktop_file.split("\n")
             if len(desktop_files_list) != 1:
@@ -131,6 +126,7 @@ class Application:
             self.name = desktop_file_config.get("Desktop Entry", "name")
             self.exec = desktop_file_config.get("Desktop Entry", "exec").split(" ")[0]
             self.icon = desktop_file_config.get("Desktop Entry", "icon", fallback=None)
+            log.info(f"get_desktop_file_data: data name='{self.name}' exec='{self.exec}' icon='{self.icon}'")
 
 
     def start_via_command(self, command=None, **kwargs):
@@ -154,11 +150,10 @@ class Application:
             if "kill" in str(key).lower():
                 kill_override = val
 
-        if self.logging:
-            log.info("".join((
+        log.info("".join((
                 f"{self.component} ",
                 f"start_via_command(self, command={command}, in_session={in_session})"
-            )))
+        )))
 
         if self.is_running() and kill_override:
             self.kill_application()
@@ -166,6 +161,9 @@ class Application:
         command_to_use = command if command else self.exec
 
         if in_session:
+            if self.kiosk:
+                raise RuntimeError("Start in session is not available in kiosk mode.")
+
             pressKey("Esc")
             keyCombo("<Alt><F2>")
             sleep(0.5)
@@ -208,8 +206,10 @@ class Application:
         in a new gnome-classic as it lost the search bar.
         """
 
-        if self.logging:
-            log.info(f"{self.component} start_via_menu(self)")
+        log.info(f"{self.component} start_via_menu(self)")
+
+        if self.kiosk:
+            raise RuntimeError("Start via menu is not available in kiosk mode.")
 
         if "classic" in self.session_desktop:
             assert False, "".join((
@@ -227,14 +227,7 @@ class Application:
         if self.is_running() and kill_override:
             self.kill_application()
 
-        run(" ".join((
-            "dbus-send",
-            "--session",
-            "--type=method_call",
-            "--dest=org.gnome.Shell",
-            "/org/gnome/Shell",
-            "org.gnome.Shell.FocusSearch"
-        )))
+        overview_action(action="show")
 
         sleep(1)
         typeText(self.name)
@@ -258,8 +251,7 @@ class Application:
             Here are  a few examples: <Ctrl><Q> <Alt><F4> <Ctrl><Shift><Q>
         """
 
-        if self.logging:
-            log.info(f"{self.component} close_via_shortcut(self)")
+        log.info(f"{self.component} close_via_shortcut(self)")
 
         if not self.is_running():
             raise Exception("".join((
@@ -279,8 +271,7 @@ class Application:
         this will retrieve the root of the application.
         """
 
-        if self.logging:
-            log.info(f"{self.component} already_running(self)")
+        log.info(f"{self.component} already_running(self)")
 
         self.wait_before_app_starts(15)
         self.instance = self.get_root()
@@ -297,9 +288,11 @@ class Application:
         You do not need to use this by yourself, but can be useful in some situations.
         """
 
-        if self.logging:
-            log.info(f"{self.component} get_root(self) search by '{self.a11y_app_name}'")
+        log.info(f"{self.component} get_root(self) search by '{self.a11y_app_name}'")
 
+        # Importing here for issue with accessibility if the connection is not ready yet.
+        # This will make sure the import will happen after the session is loaded.
+        from dogtail.tree import root
         return root.application(self.a11y_app_name)
 
 
@@ -315,12 +308,14 @@ class Application:
         You do not need to use this by yourself, but can be useful in some situations.
         """
 
-        if self.logging:
-            log.info(f"{self.component} is_running(self)")
-            
+        log.info(f"{self.component} is_running(self)")
+
         is_running = False
 
         try:
+            # Preventing issues of loading a11y on import before session is ready.
+            from dogtail.tree import root
+
             self.application_list = [x.name for x in root.applications()]
             for _ in range(3):
                 is_running = self.a11y_app_name in self.application_list
@@ -345,8 +340,7 @@ class Application:
             when stopping the application.
         """
 
-        if self.logging:
-            log.info(f"{self.component} get_pid_list(self)")
+        log.info(f"{self.component} get_pid_list(self)")
 
         if self.is_running():
             return run(f"pgrep -fla {self.app_process_name}").strip("\n")
@@ -372,8 +366,7 @@ class Application:
         This prevents testname colliding with found process so we will not kill the test itself.
         """
 
-        if self.logging:
-            log.info(f"{self.component} get_all_kill_candidates(self)")
+        log.info(f"{self.component} get_all_kill_candidates(self)")
 
         application_pid_string = self.get_pid_list()
         if application_pid_string:
@@ -391,7 +384,9 @@ class Application:
                 try:
                     final_pid_list.append(int(extracted_pid))
                 except ValueError:
-                    pass # skip non-digits
+                    # Skip non-digits.
+                    pass
+
         return final_pid_list
 
 
@@ -405,8 +400,7 @@ class Application:
         You do not need to use this by yourself, but can be useful in some situations.
         """
 
-        if self.logging:
-            log.info(f"{self.component} kill(self)")
+        log.info(f"{self.component} kill(self)")
 
         if self.is_running() and self.kill:
             if not self.kill_command:
@@ -425,12 +419,10 @@ class Application:
         :param time_limit: Number which signifies time before the run is stopped.
         """
 
-        if self.logging:
-            log.info("".join((
+        log.info("".join((
                 f"{self.component} ",
                 f"wait_before_app_starts(self, time_limit={time_limit})"
-            )))
-
+        )))
 
         for _ in range(time_limit * 10):
             if not self.is_running():
@@ -450,12 +442,10 @@ class Application:
         :param time_limit: Number which signifies time before the run is stopped.
         """
 
-        if self.logging:
-            log.info("".join((
+        log.info("".join((
                 f"{self.component} ",
                 f"wait_before_app_closes(self, time_limit={time_limit}"
-            )))
-
+        )))
 
         for _ in range(time_limit * 10):
             if self.is_running():
@@ -468,7 +458,7 @@ class Application:
         ))
 
 
-    #Using properties to preserve old api of attributes
+    # Using properties to preserve old api of attributes.
     @property
     def a11yAppName(self):
         return self.a11y_app_name
