@@ -13,7 +13,6 @@ from qecore.utility import get_application, run
 # As we cannot have online accounts yaml data in, you have to provide them yourself #
 #####################################################################################
 
-
 class Accounts:
     """
     **With this class all accounts are added and removed.**
@@ -35,8 +34,8 @@ class Accounts:
             self.application = get_application(context, "gnome-control-center")
         except Exception:
             # if its not defined in environment.
-            self.application = context.sandbox.get_app(name="gnome-control-center",
-                                                       desktopFileName="gnome-control-center")
+            self.application = context.sandbox.get_application(name="gnome-control-center",
+                                                               desktop_file_name="gnome-control-center")
 
 
     def remove_all_accounts(self):
@@ -44,7 +43,7 @@ class Accounts:
         Remove all accounts added via gnome-online-accounts.
         """
 
-        self.context.sandbox.detect_keyring()
+        self.context.sandbox._detect_keyring()
         self.application.start_via_command("gnome-control-center online-accounts")
 
         target = self.application.instance.child("Connect to your data in the cloud")
@@ -66,13 +65,12 @@ class Accounts:
         :param account_name: Name of the account.
         """
 
-        self.context.sandbox.detect_keyring()
+        self.context.sandbox._detect_keyring()
         self.application.start_via_command("gnome-control-center online-accounts")
 
         target = self.application.instance.child("Connect to your data in the cloud")
         target_panel = target.parent.findChildren(lambda x: x.roleName == "panel")[0]
-        existing_accounts = {x.name: x for x in target_panel.findChildren(lambda x:\
-            x.roleName == "label")}
+        existing_accounts = {x.name: x for x in target_panel.findChildren(lambda x: x.roleName == "label")}
         try:
             existing_accounts[account_name].click()
             self.application.instance.child("Remove Account").click()
@@ -95,9 +93,7 @@ class Accounts:
 
         target = self.application.instance.child("Connect to your data in the cloud")
         target_panel = target.parent.findChildren(lambda x: x.roleName == "panel")[0]
-        existing_accounts = [x.name for x in target_panel.findChildren(lambda x:\
-            x.roleName == "label")]
-
+        existing_accounts = [x.name for x in target_panel.findChildren(lambda x: x.roleName == "label")]
         result = False
         for account in existing_accounts:
             if account_name in account:
@@ -125,7 +121,7 @@ class Accounts:
         :param yaml_file: Location of yaml file.
         """
 
-        self.context.sandbox.detect_keyring()
+        self.context.sandbox._detect_keyring()
         self.account_data = AccountData(account_id, login=login, password=password,
                                         server=server, yaml_file=yaml_file)
         account_name = self.account_data.name
@@ -134,8 +130,7 @@ class Accounts:
 
         target = self.application.instance.child("Connect to your data in the cloud")
         target_panel = target.parent.findChildren(lambda x: x.roleName == "panel")[1]
-        accounts_to_be_added = {x.name:\
-            x for x in target_panel.findChildren(lambda x: x.roleName == "label")}
+        accounts_to_be_added = {x.name: x for x in target_panel.findChildren(lambda x: x.roleName == "label")}
         accounts_to_be_added[account_name].click()
 
         account_login_dialog = self.application.instance.child(f"{account_name} Account", "dialog")
@@ -299,13 +294,15 @@ def add_google_account(context, data, account_login_dialog):
     wait_until_progress_bar_dissapears_in(account_login_dialog)
     email_entry = account_login_dialog.child(roleName="entry")
     email_entry.click()
-    email_entry.text = data.login
+    sleep(2)
+    typeText(data.login)
     pressKey("Enter")
 
     wait_until_progress_bar_dissapears_in(account_login_dialog)
     password_entry = account_login_dialog.child(roleName="password text")
     password_entry.click()
-    password_entry.text = data.password
+    sleep(2)
+    typeText(data.password)
     pressKey("Enter")
 
     wait_until_progress_bar_dissapears_in(account_login_dialog)
@@ -331,7 +328,7 @@ def add_google_account(context, data, account_login_dialog):
     except Exception:
         pass
 
-    context.sandbox.detect_keyring()
+    context.sandbox._detect_keyring()
 
 
 def add_nextcloud_account(context, data, account_login_dialog):
@@ -364,7 +361,7 @@ def add_nextcloud_account(context, data, account_login_dialog):
     except Exception:
         pass
 
-    context.sandbox.detect_keyring()
+    context.sandbox._detect_keyring()
 
 
 def add_facebook_account(context, data, account_login_dialog):
@@ -381,6 +378,8 @@ def add_facebook_account(context, data, account_login_dialog):
     :param account_login_dialog: gnome-online-accounts dialog for given account.
     """
 
+    print("Currently missing from gnome-online-accounts - therefore unsupported.")
+
     wait_until_progress_bar_dissapears_in(account_login_dialog)
     email_entry = account_login_dialog.child(roleName="entry")
     email_entry.click()
@@ -392,11 +391,12 @@ def add_facebook_account(context, data, account_login_dialog):
     pressKey("Enter")
 
     wait_until_progress_bar_dissapears_in(account_login_dialog)
-    continue_button = account_login_dialog.findChild(lambda x:\
-        "Continue as" in x.name or x.name == "OK")
+    continue_button = account_login_dialog.findChild(
+        lambda x: "Continue as" in x.name or x.name == "OK"
+    )
     continue_button.click()
 
-    context.sandbox.detect_keyring()
+    context.sandbox._detect_keyring()
 
 
 def add_microsoft_account(context, data, account_login_dialog):
@@ -416,7 +416,8 @@ def add_microsoft_account(context, data, account_login_dialog):
     wait_until_progress_bar_dissapears_in(account_login_dialog)
     email_entry = account_login_dialog.child(roleName="entry")
     email_entry.click()
-    email_entry.text = data.login
+    sleep(2)
+    typeText(data.login)
 
     next_button = account_login_dialog.child("Next")
     next_button.click()
@@ -424,12 +425,13 @@ def add_microsoft_account(context, data, account_login_dialog):
     wait_until_progress_bar_dissapears_in(account_login_dialog)
     password_entry = account_login_dialog.child(roleName="password text")
     password_entry.click()
-    password_entry.text = data.password
+    sleep(2)
+    typeText(data.password)
 
     sign_in = account_login_dialog.child("Sign in")
     sign_in.click()
 
-    context.sandbox.detect_keyring()
+    context.sandbox._detect_keyring()
 
 
 def add_flickr_account(context, data, account_login_dialog):
@@ -446,6 +448,8 @@ def add_flickr_account(context, data, account_login_dialog):
     :param account_login_dialog: gnome-online-accounts dialog for given account.
     """
 
+    print("Currently missing from gnome-online-accounts - therefore unsupported.")
+
     wait_until_progress_bar_dissapears_in(account_login_dialog)
     email_entry = account_login_dialog.child(roleName="entry")
     email_entry.click()
@@ -475,7 +479,7 @@ def add_flickr_account(context, data, account_login_dialog):
     pressKey("PageDown")
     authorize_button.click()
 
-    context.sandbox.detect_keyring()
+    context.sandbox._detect_keyring()
 
 
 def add_pocket_account(context, data, account_login_dialog):
@@ -492,6 +496,8 @@ def add_pocket_account(context, data, account_login_dialog):
     :param account_login_dialog: gnome-online-accounts dialog for given account.
     """
 
+    print("Currently missing from gnome-online-accounts - therefore unsupported.")
+
     wait_until_progress_bar_dissapears_in(account_login_dialog)
     pressKey("PageDown")
     pressKey("PageDown")
@@ -502,8 +508,9 @@ def add_pocket_account(context, data, account_login_dialog):
 
     wait_until_progress_bar_dissapears_in(account_login_dialog)
     try:
-        assert account_login_dialog.findChild(lambda x:\
-            x.roleName == "paragraph" and x.text == "desktopqe.pocket@gmail.com", retry=False)
+        assert account_login_dialog.findChild(
+            lambda x: x.roleName == "paragraph" and x.text == "desktopqe.pocket@gmail.com",
+        retry=False)
         pressKey("PageDown")
     except Exception:
         email_entry = account_login_dialog.child("Email", "entry")
@@ -540,7 +547,7 @@ def add_pocket_account(context, data, account_login_dialog):
     except Exception:
         pass
 
-    context.sandbox.detect_keyring()
+    context.sandbox._detect_keyring()
 
 
 def add_foursquare_account(context, data, account_login_dialog):
@@ -557,6 +564,8 @@ def add_foursquare_account(context, data, account_login_dialog):
     :param account_login_dialog: gnome-online-accounts dialog for given account.
     """
 
+    print("Currently missing from gnome-online-accounts - therefore unsupported.")
+
     wait_until_progress_bar_dissapears_in(account_login_dialog)
     email_entry = account_login_dialog.child(roleName="entry")
     email_entry.click()
@@ -571,7 +580,7 @@ def add_foursquare_account(context, data, account_login_dialog):
     log_in_and_allow_button = account_login_dialog.child("Log in and allow")
     log_in_and_allow_button.click()
 
-    context.sandbox.detect_keyring()
+    context.sandbox._detect_keyring()
 
 
 def add_microsoft_exchange_account(context, data, account_login_dialog):
@@ -614,7 +623,7 @@ def add_microsoft_exchange_account(context, data, account_login_dialog):
         sleep(0.2)
     ignore_button.click()
 
-    context.sandbox.detect_keyring()
+    context.sandbox._detect_keyring()
 
 
 @step('Add "{account_name}" account')
