@@ -31,9 +31,11 @@ def get_application(context, application):
 
     app_class_to_return = None
     try:
-        app_class_to_return = getattr(context, application) # get app from environment file
+        # Get app from environment file.
+        app_class_to_return = getattr(context, application)
     except AttributeError:
-        for app in context.sandbox.applications: # get app from sandbox application list
+        # Get app from sandbox application list.
+        for app in context.sandbox.applications:
             if app.component == application:
                 app_class_to_return = app
                 break
@@ -109,7 +111,79 @@ def run(command, verbose=False):
         return error.output if not verbose else (error.output, error.returncode, error)
 
 
-#behave-common-steps leftover
+def run_embed(context, command, *a, **kw):
+    """
+    Execute a command and get output.
+    This version of command run will also embed results to the html log.
+
+    :type context: <behave.runner.Context>
+    :param context: Context object that will be used embedding.
+
+    :type command: str
+    :param command: Command to be executed.
+
+    :rtype: list
+    :return: Return list with following format (output, return code, exception).
+    """
+
+    try:
+        output = check_output(command, shell=True, stderr=STDOUT, *a, **kw, encoding="utf-8")
+        return_code = 0
+        error = None
+    except CalledProcessError as error:
+        output = error.output
+        return_code = error.returncode
+        error = error
+
+    context.embed("text/plain", f"$?={return_code}", caption=f"{command} result")
+    context.embed("text/plain", output, caption=f"{command} output")
+
+    return (error.output, error.returncode, error)
+
+
+def overview_action(action="hide") -> None:
+    """
+    Hide or show application overview.
+
+    :type action: str
+    :param action: Hide or show application overview.
+
+    This function takes only 'hide' and 'show' value.
+    """
+
+    # DBus calls are deprecated - https://gitlab.gnome.org/GNOME/gnome-shell/-/merge_requests/1970
+
+    assert action in ["hide", "show"], "".join((
+            "Unknown option, only defined ones are 'show' or 'hide'.",
+            f"You tried to use: '{action}'"
+        ))
+
+    from dogtail.tree import root
+    gnome_shell = root.application("gnome-shell")
+
+    activities_label = gnome_shell.findChildren(
+        lambda x: x.name == "Activities" and x.roleName == "label"
+    )
+
+    if len(activities_label) == 1:
+        from dogtail.predicate import GenericPredicate
+
+        # Find Ancestor unfortunatelly takes only Predicates not lambdas alone, will use it since implementing it here would be too long.
+        activities_toggle_button = activities_label[0].findAncestor(GenericPredicate(roleName="toggle button"))
+
+        for _ in range(5):
+            if (action == "hide" and activities_toggle_button.checked) or (action == "show" and not activities_toggle_button.checked):
+                activities_toggle_button.click()
+                sleep(1)
+
+            else:
+                return
+
+    else:
+        pass # possibly in gnome-classic
+
+
+# behave-common-steps leftover.
 def wait_until(tested, element=None, timeout=30, period=0.25, params_in_list=False):
     """
     This function keeps running lambda with specified params until the
@@ -134,11 +208,11 @@ def wait_until(tested, element=None, timeout=30, period=0.25, params_in_list=Fal
 
     if isinstance(tested, bool):
         curried_func = lambda: tested
-    # or if callable(tested) and element is a list or a tuple
+    # Or if callable(tested) and element is a list or a tuple.
     elif isinstance(tested, FunctionType) and \
             isinstance(element, (tuple, list)) and params_in_list:
         curried_func = partial(tested, *element)
-    # or if callable(tested) and element is not None?
+    # Or if callable(tested) and element is not None?
     elif isinstance(tested, FunctionType) and element is not None:
         curried_func = partial(tested, element)
     else:
@@ -152,7 +226,7 @@ def wait_until(tested, element=None, timeout=30, period=0.25, params_in_list=Fal
                 return True
         except Exception as error:  # pylint: disable=broad-except
             # If lambda has thrown the exception we'll re-raise it later
-            # and forget about if lambda passes
+            # and forget about if lambda passes.
             exception_thrown = error
         sleep(period)
     if exception_thrown is not None:
@@ -202,7 +276,7 @@ class Tuple(tuple):
     def __rmul__(self, other):
         return Tuple(other * x for x in self)
     def __eq__(self, other):
-        return (x == y for x, y in zip(self, other))
+        return all(x == y for x, y in zip(self, other))
     def __lt__(self, other):
         return self[0] < other[0] or self[1] < other[1]
     def __gt__(self, other):
@@ -262,7 +336,6 @@ def plain_dump(node):
             crawl(child, depth + 1)
 
     def dump_std_out(item, depth):
-        # str wont possibly work in p3
         print(SPACER * depth + str(item) + \
             f"     [p:{item.position}, s:{item.size}, vis:{item.visible}, show:{item.showing}]")
 
